#[repr(i32)]pub enum ColumnType {
Show 32 variants
Boolean = 0,
Int8 = 1,
Int16 = 2,
Int32 = 3,
Int64 = 4,
Uint8 = 5,
Uint16 = 6,
Uint32 = 7,
Uint64 = 8,
Float32 = 9,
Float64 = 10,
Binary = 11,
String = 12,
Date = 13,
Datetime = 14,
TimestampSecond = 15,
TimestampMillisecond = 16,
TimestampMicrosecond = 17,
TimestampNanosecond = 18,
TimeSecond = 19,
TimeMillisecond = 20,
TimeMicrosecond = 21,
TimeNanosecond = 22,
IntervalYearMonth = 23,
IntervalDayTime = 24,
IntervalMonthDayNano = 25,
Decimal128 = 30,
Json = 31,
Vector = 32,
List = 40,
Struct = 41,
Dictionary = 42,
}Variants
Boolean = 0
Int8 = 1
Int16 = 2
Int32 = 3
Int64 = 4
Uint8 = 5
Uint16 = 6
Uint32 = 7
Uint64 = 8
Float32 = 9
Float64 = 10
Binary = 11
String = 12
Date = 13
Datetime = 14
TimestampSecond = 15
TimestampMillisecond = 16
TimestampMicrosecond = 17
TimestampNanosecond = 18
TimeSecond = 19
TimeMillisecond = 20
TimeMicrosecond = 21
TimeNanosecond = 22
IntervalYearMonth = 23
IntervalDayTime = 24
IntervalMonthDayNano = 25
Decimal128 = 30
Json = 31
Vector = 32
List = 40
Struct = 41
Dictionary = 42
Implementations
Sourceimpl ColumnDataType
impl ColumnDataType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ColumnDataType>
pub fn from_str_name(value: &str) -> Option<ColumnDataType>
Creates an enum from field names used in the ProtoBuf definition.