Row

Struct Row 

pub struct Row { /* private fields */ }
Represents a data row with type-safe value access

Implementations

Source

impl Row

pub fn new() -> Self

Create a new empty row

pub fn with_capacity(capacity: usize) -> Self

Create a new row with pre-allocated capacity

pub fn len(&self) -> usize

Get the number of values in the row

pub fn is_empty(&self) -> bool

Check if the row is empty

pub fn from_values(values: Vec<Value>) -> Self

Create a row directly from values (more efficient than chaining add_value calls)

pub fn add_value(self, value: Value) -> Self

Add a value to the row

pub fn add_values(self, values: Vec<Value>) -> Self

Add multiple values to the row

pub fn add_values_iter(self, values: impl IntoIterator<Item = Value>) -> Self

Add multiple values from an iterator

pub fn get_bool(&self, index: usize) -> Option<bool>

Get boolean value at index (safe version with bounds checking)

pub unsafe fn get_bool_unchecked(&self, index: usize) -> Option<bool>

Get boolean value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_i8(&self, index: usize) -> Option<i8>

Get i8 value at index (safe version with bounds checking)

pub unsafe fn get_i8_unchecked(&self, index: usize) -> Option<i8>

Get i8 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_i16(&self, index: usize) -> Option<i16>

Get i16 value at index (safe version with bounds checking)

pub unsafe fn get_i16_unchecked(&self, index: usize) -> Option<i16>

Get i16 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_i32(&self, index: usize) -> Option<i32>

Get i32 value at index (safe version with bounds checking)

pub unsafe fn get_i32_unchecked(&self, index: usize) -> Option<i32>

Get i32 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_i64(&self, index: usize) -> Option<i64>

Get i64 value at index (safe version with bounds checking)

pub unsafe fn get_i64_unchecked(&self, index: usize) -> Option<i64>

Get i64 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_u8(&self, index: usize) -> Option<u8>

Get u8 value at index (safe version with bounds checking)

pub unsafe fn get_u8_unchecked(&self, index: usize) -> Option<u8>

Get u8 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_u16(&self, index: usize) -> Option<u16>

Get u16 value at index (safe version with bounds checking)

pub unsafe fn get_u16_unchecked(&self, index: usize) -> Option<u16>

Get u16 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_u32(&self, index: usize) -> Option<u32>

Get u32 value at index (safe version with bounds checking)

pub unsafe fn get_u32_unchecked(&self, index: usize) -> Option<u32>

Get u32 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_u64(&self, index: usize) -> Option<u64>

Get u64 value at index (safe version with bounds checking)

pub unsafe fn get_u64_unchecked(&self, index: usize) -> Option<u64>

Get u64 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_f32(&self, index: usize) -> Option<f32>

Get f32 value at index (safe version with bounds checking)

pub unsafe fn get_f32_unchecked(&self, index: usize) -> Option<f32>

Get f32 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_f64(&self, index: usize) -> Option<f64>

Get f64 value at index (safe version with bounds checking)

pub unsafe fn get_f64_unchecked(&self, index: usize) -> Option<f64>

Get f64 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_binary(&self, index: usize) -> Option<Vec<u8>>

Get binary value at index (safe version with bounds checking)

pub unsafe fn get_binary_unchecked(&self, index: usize) -> Option<Vec<u8>>

Get binary value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn take_binary(&mut self, index: usize) -> Option<Vec<u8>>

Take binary value at index (safe version with bounds checking)

pub unsafe fn take_binary_unchecked(&mut self, index: usize) -> Option<Vec<u8>>

Take binary value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_string(&self, index: usize) -> Option<String>

Get string value at index (safe version with bounds checking)

pub unsafe fn get_string_unchecked(&self, index: usize) -> Option<String>

Get string value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn take_string(&mut self, index: usize) -> Option<String>

Take string value at index (safe version with bounds checking)

pub unsafe fn take_string_unchecked(&mut self, index: usize) -> Option<String>

Take string value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_date(&self, index: usize) -> Option<i32>

Get date value at index (safe version with bounds checking)

pub unsafe fn get_date_unchecked(&self, index: usize) -> Option<i32>

Get date value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_datetime(&self, index: usize) -> Option<i64>

Get datetime value at index (safe version with bounds checking)

pub unsafe fn get_datetime_unchecked(&self, index: usize) -> Option<i64>

Get datetime value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_timestamp(&self, index: usize) -> Option<i64>

Get timestamp value at index (generic, supports all timestamp types, safe version with bounds checking)

pub unsafe fn get_timestamp_unchecked(&self, index: usize) -> Option<i64>

Get timestamp value at index (generic, supports all timestamp types, unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_time32(&self, index: usize) -> Option<i32>

Get time32 value at index (safe version with bounds checking)

pub unsafe fn get_time32_unchecked(&self, index: usize) -> Option<i32>

Get time32 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_time64(&self, index: usize) -> Option<i64>

Get time64 value at index (safe version with bounds checking)

pub unsafe fn get_time64_unchecked(&self, index: usize) -> Option<i64>

Get time64 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()

pub fn get_decimal128(&self, index: usize) -> Option<i128>

Get decimal128 value at index (safe version with bounds checking)

pub unsafe fn get_decimal128_unchecked(&self, index: usize) -> Option<i128>

Get decimal128 value at index (unsafe version without bounds checking)

Safety

The caller must ensure that index < self.values.len()